@@ -8,7 +8,7 @@ from rest_framework.routers import DefaultRouter
 
 from enterprise_data.api.v0 import views
 
-app_name = 'enterprise_data_api_v0'  # pylint: disable=invalid-name
+app_name = 'enterprise_data_api_v0'
 
 router = DefaultRouter()  # pylint: disable=invalid-name
 router.register(
