@@ -3,11 +3,11 @@
 Tests for views in the `enterprise_data` module.
 """
 
-
 from datetime import date, datetime, timedelta
 
 import ddt
 import mock
+import pytz
 from pytest import mark
 from rest_framework import status
 from rest_framework.reverse import reverse
@@ -17,7 +17,7 @@ from django.utils import timezone
 
 from enterprise_data.api.v0.serializers import EnterpriseEnrollmentSerializer
 from enterprise_data.api.v0.views import subtract_one_month
-from enterprise_data.models import EnterpriseEnrollment
+from enterprise_data.models import EnterpriseEnrollment, EnterpriseUser
 from enterprise_data.tests.mixins import JWTTestMixin
 from enterprise_data.tests.test_utils import (
     EnterpriseEnrollmentFactory,
@@ -62,6 +62,11 @@ class TestEnterpriseEnrollmentsViewSet(JWTTestMixin, APITransactionTestCase):
         self.enterprise_id = 'ee5e6b3a-069a-4947-bb8d-d2dbc323396c'
         self.set_jwt_cookie()
 
+    def tearDown(self):
+        super(TestEnterpriseEnrollmentsViewSet, self).tearDown()
+        EnterpriseUser.objects.all().delete()
+        EnterpriseEnrollment.objects.all().delete()
+
     @staticmethod
     def _get_enrollments_expected_data(enrollments):
         """
@@ -185,34 +190,6 @@ class TestEnterpriseEnrollmentsViewSet(JWTTestMixin, APITransactionTestCase):
         result = response.json()
         assert result == expected_result
 
-    @ddt.data(
-        ('test_1234@example.com', 1),
-        ('test_1234', 1),
-        ('test_5678@example.com', 0),
-    )
-    @ddt.unpack
-    def test_get_enterprise_enrollments_with_email_search(self, search_email, expected_count):
-        """Test that with email_search param we get correct results"""
-        enterprise_user = EnterpriseUserFactory(enterprise_id=self.enterprise_id, user_email=search_email)
-        EnterpriseEnrollmentFactory(
-            enterprise_user=enterprise_user,
-            enterprise_id=self.enterprise_id,
-            user_email='test_1234@example.com',
-            consent_granted=True,
-        )
-
-        enrollments = EnterpriseEnrollment.objects.filter(
-            enterprise_id=self.enterprise_id,
-            user_email__icontains=search_email
-        )
-        expected_response = self._get_enrollments_expected_data(enrollments)
-        response = self.client.get(
-            reverse('v0:enterprise-enrollments-list', kwargs={'enterprise_id': self.enterprise_id}),
-            data={'search': search_email}
-        ).json()
-        assert response['count'] == expected_count
-        assert response == expected_response
-
     def test_get_queryset_returns_no_enrollments(self):
         """ Test that enterprise with no enrollments returns empty list """
         enterprise = EnterpriseUserFactory()
@@ -234,7 +211,7 @@ class TestEnterpriseEnrollmentsViewSet(JWTTestMixin, APITransactionTestCase):
     def test_get_queryset_returns_enrollments_with_passed_date_filter(self):
         enterprise = EnterpriseUserFactory()
         enterprise_id = enterprise.enterprise_id
-        url = u"{url}?passed_date=last_week".format(
+        url = "{url}?passed_date=last_week".format(
             url=reverse('v0:enterprise-enrollments-list', kwargs={'enterprise_id': enterprise_id})
         )
 
@@ -360,9 +337,10 @@ class TestEnterpriseEnrollmentsViewSet(JWTTestMixin, APITransactionTestCase):
     )
     @ddt.unpack
     def test_get_queryset_returns_enrollments_with_learner_activity_filter(self, activity_filter, expected_dates):
+
         enterprise = EnterpriseUserFactory()
         enterprise_id = enterprise.enterprise_id
-        url = u"{url}?learner_activity={activity_filter}".format(
+        url = "{url}?learner_activity={activity_filter}".format(
             url=reverse('v0:enterprise-enrollments-list', kwargs={'enterprise_id': enterprise_id}),
             activity_filter=activity_filter
         )
@@ -372,14 +350,17 @@ class TestEnterpriseEnrollmentsViewSet(JWTTestMixin, APITransactionTestCase):
         before_past_week_dates = [date_today - timedelta(weeks=2)]
         before_past_month_dates = [subtract_one_month(date.today())]
         activity_dates = in_past_week_dates + before_past_week_dates + before_past_month_dates
+        start_date = timezone.now() - timedelta(days=60)
+        end_date = timezone.now() + timedelta(days=1)
+
         for activity_date in activity_dates:
             EnterpriseEnrollmentFactory(
                 enterprise_user=enterprise,
                 enterprise_id=enterprise_id,
                 last_activity_date=activity_date,
-                course_end=timezone.now() + timedelta(days=1),
-                has_passed=False,
-                consent_granted=True,
+                course_start=start_date,
+                course_end=end_date,
+                has_passed=False
             )
 
         response = self.client.get(url)
@@ -408,7 +389,7 @@ class TestEnterpriseEnrollmentsViewSet(JWTTestMixin, APITransactionTestCase):
         """
         enterprise = EnterpriseUserFactory()
         enterprise_id = enterprise.enterprise_id
-        url = u"{url}?learner_activity={activity_filter}".format(
+        url = "{url}?learner_activity={activity_filter}".format(
             url=reverse('v0:enterprise-enrollments-list', kwargs={'enterprise_id': enterprise_id}),
             activity_filter=activity_filter
         )
@@ -493,7 +474,7 @@ class TestEnterpriseEnrollmentsViewSet(JWTTestMixin, APITransactionTestCase):
         """
         enterprise = EnterpriseUserFactory()
         enterprise_id = enterprise.enterprise_id
-        url = u"{url}?learner_activity={activity_filter}".format(
+        url = "{url}?learner_activity={activity_filter}".format(
             url=reverse('v0:enterprise-enrollments-list', kwargs={'enterprise_id': enterprise_id}),
             activity_filter=activity_filter
         )
@@ -508,6 +489,7 @@ class TestEnterpriseEnrollmentsViewSet(JWTTestMixin, APITransactionTestCase):
                 enterprise_user=enterprise,
                 enterprise_id=enterprise_id,
                 last_activity_date=activity_date,
+                course_start=course_end_date - timedelta(days=60),
                 course_end=course_end_date,
                 has_passed=has_passed,
                 consent_granted=True,
@@ -702,8 +684,10 @@ class TestEnterpriseUsersViewSet(JWTTestMixin, APITransactionTestCase):
         self.enterprise_id = 'ee5e6b3a-069a-4947-bb8d-d2dbc323396c'
 
         one_day = timedelta(days=1)
-        date_in_past = timezone.now() - one_day
-        date_in_future = timezone.now() + one_day
+        self.today = timezone.now()
+        course_end_date_in_past = self.today - one_day
+        course_end_date_in_future = self.today + one_day
+        course_start_date = course_end_date_in_future - timedelta(days=60)
 
         # Users without enrollments
         EnterpriseUserFactory(
@@ -725,25 +709,30 @@ class TestEnterpriseUsersViewSet(JWTTestMixin, APITransactionTestCase):
         )
         EnterpriseEnrollmentFactory(
             enterprise_user=self.ent_user4,
-            course_end=date_in_past,
+            course_start=course_start_date,
+            course_end=course_end_date_in_past,
             consent_granted=True,
             has_passed=True,
             enterprise_id=self.enterprise_id,
         )
         EnterpriseEnrollmentFactory(
             enterprise_user=self.ent_user4,
-            course_end=date_in_future,
+            course_start=course_start_date,
+            course_end=course_end_date_in_future,
             enterprise_id=self.enterprise_id,
+            consent_granted=None,
         )
         EnterpriseEnrollmentFactory(
             enterprise_user=self.ent_user4,
-            course_end=date_in_future,
+            course_start=course_start_date,
+            course_end=course_end_date_in_future,
             consent_granted=True,
             enterprise_id=self.enterprise_id,
         )
         EnterpriseEnrollmentFactory(
             enterprise_user=self.ent_user4,
-            course_end=date_in_past,
+            course_start=course_start_date,
+            course_end=course_end_date_in_past,
             consent_granted=True,
             has_passed=False,
             enterprise_id=self.enterprise_id,
@@ -755,7 +744,8 @@ class TestEnterpriseUsersViewSet(JWTTestMixin, APITransactionTestCase):
         )
         EnterpriseEnrollmentFactory(
             enterprise_user=self.ent_user5,
-            course_end=date_in_future,
+            course_start=course_start_date,
+            course_end=course_end_date_in_future,
             consent_granted=True,
             enterprise_id=self.enterprise_id,
         )
@@ -767,7 +757,8 @@ class TestEnterpriseUsersViewSet(JWTTestMixin, APITransactionTestCase):
         EnterpriseEnrollmentFactory(
             enterprise_user=self.ent_user6,
             consent_granted=False,
-            course_end=date_in_past,
+            course_start=course_start_date,
+            course_end=course_end_date_in_past,
             enterprise_id=self.enterprise_id,
         )
         # User with True and False enrollment consent
@@ -780,18 +771,22 @@ class TestEnterpriseUsersViewSet(JWTTestMixin, APITransactionTestCase):
             consent_granted=True,
             has_passed=True,
             enterprise_id=self.enterprise_id,
+            course_start=course_start_date,
+            course_end=course_end_date_in_future,
         )
         EnterpriseEnrollmentFactory(
             enterprise_user=self.ent_user7,
             consent_granted=False,
-            course_end=date_in_future,
+            course_start=course_start_date,
+            course_end=course_end_date_in_future,
             has_passed=False,
             enterprise_id=self.enterprise_id,
         )
         EnterpriseEnrollmentFactory(
             enterprise_user=self.ent_user7,
             consent_granted=False,
-            course_end=date_in_past,
+            course_start=course_start_date,
+            course_end=course_end_date_in_past,
             has_passed=True,
             enterprise_id=self.enterprise_id,
         )
@@ -803,14 +798,17 @@ class TestEnterpriseUsersViewSet(JWTTestMixin, APITransactionTestCase):
         )
         EnterpriseEnrollmentFactory(
             enterprise_user=self.ent_user8,
-            course_end=date_in_past,
+            course_start=course_start_date,
+            course_end=course_end_date_in_past,
             has_passed=True,
             enterprise_id=self.enterprise_id,
+            consent_granted=None,
         )
         EnterpriseEnrollmentFactory(
             enterprise_user=self.ent_user8,
             consent_granted=True,
-            course_end=date_in_past,
+            course_start=course_start_date,
+            course_end=course_end_date_in_past,
             has_passed=True,
             enterprise_id=self.enterprise_id,
         )
@@ -823,13 +821,19 @@ class TestEnterpriseUsersViewSet(JWTTestMixin, APITransactionTestCase):
         EnterpriseEnrollmentFactory(
             enterprise_user=self.ent_user9,
             has_passed=True,
+            consent_granted=False,
             enterprise_id=self.enterprise_id,
+            course_start=course_start_date,
+            course_end=course_end_date_in_future,
         )
         for _ in range(2):
             EnterpriseEnrollmentFactory(
                 enterprise_user=self.ent_user9,
                 has_passed=False,
                 enterprise_id=self.enterprise_id,
+                consent_granted=False,
+                course_start=course_start_date,
+                course_end=course_end_date_in_future,
             )
         for _ in range(3):
             EnterpriseEnrollmentFactory(
@@ -837,18 +841,24 @@ class TestEnterpriseUsersViewSet(JWTTestMixin, APITransactionTestCase):
                 consent_granted=True,
                 has_passed=True,
                 enterprise_id=self.enterprise_id,
+                course_start=course_start_date,
+                course_end=course_end_date_in_future,
             )
         EnterpriseEnrollmentFactory(
             enterprise_user=self.ent_user9,
             consent_granted=False,
             has_passed=True,
             enterprise_id=self.enterprise_id,
+            course_start=course_start_date,
+            course_end=course_end_date_in_future,
         )
         EnterpriseEnrollmentFactory(
             enterprise_user=self.ent_user9,
             consent_granted=True,
             has_passed=False,
             enterprise_id=self.enterprise_id,
+            course_start=course_start_date,
+            course_end=course_end_date_in_future,
         )
 
         # User with a audit mode enrollment
@@ -862,9 +872,16 @@ class TestEnterpriseUsersViewSet(JWTTestMixin, APITransactionTestCase):
             enterprise_id=self.enterprise_id,
             consent_granted=True,
             user_current_enrollment_mode='audit',
+            course_start=course_start_date,
+            course_end=course_end_date_in_future,
         )
         self.set_jwt_cookie()
 
+    def tearDown(self):
+        super(TestEnterpriseUsersViewSet, self).tearDown()
+        EnterpriseUser.objects.all().delete()
+        EnterpriseEnrollment.objects.all().delete()
+
     def test_viewset_no_query_params(self):
         """
         EnterpriseUserViewset should return all users if no filtering query
@@ -953,14 +970,15 @@ class TestEnterpriseUsersViewSet(JWTTestMixin, APITransactionTestCase):
             'v0:enterprise-users-list',
             kwargs=kwargs,
         )
+
         response = self.client.get(url, params)
-        assert response.json()['count'] == 2
+        assert response.json()['count'] == 4
 
     def test_viewset_filter_active_courses_false(self):
         """
         EnterpriseUserViewset should filter out enrollments for courses that
         have a course_end date in the future if active_courses query param
-        value is true
+        value is false
         """
         kwargs = {'enterprise_id': self.enterprise_id, }
         params = {'active_courses': 'false', }
@@ -1057,8 +1075,9 @@ class TestEnterpriseUsersViewSet(JWTTestMixin, APITransactionTestCase):
             kwargs=kwargs,
         )
         response = self.client.get(url, params)
-        assert response.json()['enrollment_count'] == 3
-        assert response.json()['course_completion_count'] == 1
+        # There will be a KeyError if the key is not present
+        assert response.json()['enrollment_count']
+        assert response.json()['course_completion_count']
 
     def test_viewset_enrollment_count_consent(self):
         """
@@ -1386,6 +1405,11 @@ class TestEnterpriseLearnerCompletedCourses(JWTTestMixin, APITransactionTestCase
 
         self.set_jwt_cookie()
 
+    def tearDown(self):
+        super(TestEnterpriseLearnerCompletedCourses, self).tearDown()
+        EnterpriseUser.objects.all().delete()
+        EnterpriseEnrollment.objects.all().delete()
+
     def test_get_learner_completed_courses(self):
         """
         Test that we get correct number of courses completed by a learner.
@@ -1510,6 +1534,7 @@ class TestEnterpriseLearnerCompletedCourses(JWTTestMixin, APITransactionTestCase
         # Add enrollments
         one_day = timedelta(days=1)
         date_in_past = timezone.now() - one_day
+        course_start = date_in_past - timedelta(days=60)
         ent_user = EnterpriseUserFactory(enterprise_id=self.enterprise_id)
         for enrollment in enrollments_data:
             for _idx in range(enrollment['user_enrollments']):
@@ -1518,6 +1543,7 @@ class TestEnterpriseLearnerCompletedCourses(JWTTestMixin, APITransactionTestCase
                     enterprise_user=ent_user,
                     enterprise_id=self.enterprise_id,
                     course_end=date_in_past,
+                    course_start=course_start,
                     has_passed=True,
                     consent_granted=True,
                 )
@@ -1627,3 +1653,186 @@ class TestEnterpriseLearnerCompletedCourses(JWTTestMixin, APITransactionTestCase
         response = self.client.get(url)
 
         assert response.status_code == status.HTTP_200_OK
+
+
+@ddt.ddt
+@mark.django_db
+class TestEnterpriseEnrollmentsViewSetFilters(JWTTestMixin, APITransactionTestCase):
+    """
+    Tests for EnterpriseEnrollmentsViewSet
+    """
+    fixtures = ('enterprise_enrollment', 'enterprise_user', )
+
+    def setUp(self):
+        super(TestEnterpriseEnrollmentsViewSetFilters, self).setUp()
+        self.user = UserFactory(is_staff=True)
+        role, __ = EnterpriseDataFeatureRole.objects.get_or_create(name=ENTERPRISE_DATA_ADMIN_ROLE)
+        self.role_assignment = EnterpriseDataRoleAssignment.objects.create(
+            role=role,
+            user=self.user
+        )
+        self.client.force_authenticate(user=self.user)  # pylint: disable=no-member
+
+        mocked_get_enterprise_customer = mock.patch(
+            'enterprise_data.filters.EnterpriseApiClient.get_enterprise_customer',
+            return_value=get_dummy_enterprise_api_data()
+        )
+
+        self.mocked_get_enterprise_customer = mocked_get_enterprise_customer.start()
+        self.addCleanup(mocked_get_enterprise_customer.stop)
+        self.enterprise_id = 'ee5e6b3a-069a-4947-bb8d-d2dbc323396c'
+        self.set_jwt_cookie()
+
+        self.email_0 = "robot@robot.com"
+        self.email_1 = "mrrobot@foo.com"
+        self.email_2 = "definitelyHuman@bar.com"
+        self.enterprise_user_0 = EnterpriseUserFactory(enterprise_id=self.enterprise_id, user_email=self.email_0)
+        self.enterprise_user_1 = EnterpriseUserFactory(enterprise_id=self.enterprise_id, user_email=self.email_1)
+        self.enterprise_user_2 = EnterpriseUserFactory(enterprise_id=self.enterprise_id, user_email=self.email_2)
+
+        self.course_title_0 = "Beekeeping 101"
+        self.course_title_1 = "Keeping it together"
+        self.course_title_2 = "Plan 101"
+
+        self.course_date_0 = pytz.utc.localize(datetime(2020, 9, 30))
+        self.course_date_1 = pytz.utc.localize(datetime(2020, 9, 3))
+        self.course_date_2 = pytz.utc.localize(datetime(2020, 8, 30))
+
+        self.all_course_titles = [self.course_title_0, self.course_title_1, self.course_title_2]
+        self.all_course_dates = [self.course_date_0, self.course_date_1, self.course_date_2]
+        self.all_emails = [self.email_0, self.email_1, self.email_2]
+
+        # User 1 is enrolled in each course title with it's corresponding course date
+        for course_date, title in zip(self.all_course_dates, self.all_course_titles):
+            EnterpriseEnrollmentFactory(
+                enterprise_user=self.enterprise_user_0,
+                enterprise_id=self.enterprise_id,
+                user_email=self.enterprise_user_0.user_email,
+                consent_granted=True,
+                course_title=title,
+                course_start=course_date,
+            )
+
+        # User 2 is enrolled in the same first two courses and titles as user1
+        for course_date, title in zip(
+                                      [self.course_date_0, self.course_date_1],
+                                      [self.course_title_0, self.course_title_1]):
+            EnterpriseEnrollmentFactory(
+                enterprise_user=self.enterprise_user_1,
+                enterprise_id=self.enterprise_id,
+                user_email=self.enterprise_user_1.user_email,
+                consent_granted=True,
+                course_title=title,
+                course_start=course_date,
+            )
+
+        # User 3 is enrolled in the first course, but a different course run (different date)
+        EnterpriseEnrollmentFactory(
+                enterprise_user=self.enterprise_user_2,
+                enterprise_id=self.enterprise_id,
+                user_email=self.enterprise_user_2.user_email,
+                consent_granted=True,
+                course_title=self.course_title_0,
+                course_start=self.course_date_1,
+            )
+
+    def tearDown(self):
+        super(TestEnterpriseEnrollmentsViewSetFilters, self).tearDown()
+        EnterpriseUser.objects.all().delete()
+        EnterpriseEnrollment.objects.all().delete()
+
+    @ddt.data(
+        ("robot@robot.com", 3),  # the user with this email has 3 enrollements
+        ('robot', 5),  # Two users have 'robot' in their emails, between them there are 5 enrollments
+        ('human', 1),  # The user with 'human' in their email has only one enrollment
+        ('test_5678@example.com', 0),  # there is no user with this email
+    )
+    @ddt.unpack
+    def test_get_enterprise_enrollments_with_email_search(self, search_email, expected_count):
+        """Test that with email_search param we get correct results"""
+
+        expected_emails = [email for email in self.all_emails if search_email.lower() in email.lower()]
+        response = self.client.get(
+            reverse('v0:enterprise-enrollments-list', kwargs={'enterprise_id': self.enterprise_id}),
+            data={'search': search_email}
+        ).json()
+
+        assert response['count'] == expected_count
+        for result in response['results']:
+            assert result['user_email'] in expected_emails
+
+    @ddt.data(
+        ('keep', 5),  # there are 5 enrollments in the that have 'keep' in their title
+        ('Beekeep', 3),  # there are only 3 enrollments with 'Beekeep' in their title
+        ('plan', 1)  # there is only one enrollment with 'plan' in the title
+    )
+    @ddt.unpack
+    def test_get_enterprise_enrollments_with_course_search(self, search_course, expected_count):
+        expected_titles = [title for title in self.all_course_titles if search_course.lower() in title.lower()]
+        response = self.client.get(
+            reverse('v0:enterprise-enrollments-list', kwargs={'enterprise_id': self.enterprise_id}),
+            data={'search_course': search_course}
+        ).json()
+        response = self.client.get(
+            reverse('v0:enterprise-enrollments-list', kwargs={'enterprise_id': self.enterprise_id}),
+            data={'search_course': search_course}
+        ).json()
+
+        assert response['count'] == expected_count
+
+        for result in response["results"]:
+            assert result["course_title"] in expected_titles
+
+    # the expected_count corresponds to the number of enrollments that have that start date
+    @ddt.data(
+        ('2020-09-30T00:00:00Z', 2),
+        ('2020-09-03T00:00:00Z', 3),
+        ('2020-08-30T00:00:00Z', 1)
+    )
+    @ddt.unpack
+    def test_get_enterprise_enrollments_with_start_date_search(self, search_date, expected_count):
+        response = self.client.get(
+            reverse('v0:enterprise-enrollments-list', kwargs={'enterprise_id': self.enterprise_id}),
+            data={'search_start_date': search_date}
+        ).json()
+
+        assert response['count'] == expected_count
+
+        for result in response["results"]:
+            assert result["course_start"] == search_date
+
+    @ddt.data(
+        ("", "keep", "2020-09-03T00:00:00Z", 3),  # of the 5 courses with keep in the name, 3 start on this date
+        ("robot", "", "2020-09-03T00:00:00Z", 2),  # 2 users have 'robot' emails who have enrollments on this date
+        ("robot", "Beekeep", "", 2),  # 2 users have the 'robot' email, each is enrolled in a Beekeeping course
+        ("robot@robot.com", "keep", "2020-09-03T00:00:00Z", 1),  # there is only one enrollment that matches
+        ("mrrobot@foo.com", "Plan", "", 0)  # user email exists, but the user has no courses with plan in the title
+    )
+    @ddt.unpack
+    def test_get_enrollments_multiple_filters(self, search_email, search_course, search_date, expected_count):
+        """ Integration test ensuring that filters work together as expected """
+
+        expected_titles = [title for title in self.all_course_titles if search_course.lower() in title.lower()]
+        expected_emails = [email for email in self.all_emails if search_email.lower() in email.lower()]
+        data_dict = dict()
+        if search_date:
+            data_dict["search_start_date"] = search_date
+        if search_course:
+            data_dict["search_course"] = search_course
+        if search_email:
+            data_dict["search"] = search_email
+
+        response = self.client.get(
+            reverse('v0:enterprise-enrollments-list', kwargs={'enterprise_id': self.enterprise_id}),
+            data=data_dict
+        ).json()
+
+        assert response['count'] == expected_count
+
+        for result in response["results"]:
+            if search_date:
+                assert result["course_start"] == search_date
+            if search_course:
+                assert result["course_title"] in expected_titles
+            if search_email:
+                assert result["user_email"] in expected_emails
